@@ -124,7 +124,7 @@ class WalkSFTP:
                 stat_bool = not stat.st_size is None
                 
                 if self.check_ch_dir(self, f):
-                    return False None
+                    return False, None
                 
                 return stat_bool, stat_mtime
             except:
